==> jc-tke-client-1.1.284-sources.jar: com/xforceplus/ultraman/app/jctke/controller/FlowinstancelogLrr94edwdqrcw2ajregmnmFeignApi.java <==
package com.xforceplus.ultraman.app.jctke.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2022-10-11
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.jctke.entity.FlowinstancelogLrr94edwdqrcw2ajregmnm;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-tke")
public interface FlowinstancelogLrr94edwdqrcw2ajregmnmFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/flowinstancelogLrr94edwdqrcw2ajregmnm/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param flowinstancelogLrr94edwdqrcw2ajregmnm ${table.comment}
   * @return R
   */
  @PostMapping("/flowinstancelogLrr94edwdqrcw2ajregmnm/add")
  public R save(@RequestBody FlowinstancelogLrr94edwdqrcw2ajregmnm flowinstancelogLrr94edwdqrcw2ajregmnm);

  /**
   * 修改${table.comment}
   * @param flowinstancelogLrr94edwdqrcw2ajregmnm ${table.comment}
   * @return R
   */
  @PostMapping("/flowinstancelogLrr94edwdqrcw2ajregmnm/update")
  public R updateById(@RequestBody FlowinstancelogLrr94edwdqrcw2ajregmnm flowinstancelogLrr94edwdqrcw2ajregmnm);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/flowinstancelogLrr94edwdqrcw2ajregmnm/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> jc-tke-client-1.1.346-sources.jar: com/xforceplus/ultraman/app/jctke/controller/FlowinstancelogLrr94edwdqrcw2ajregmnmFeignApi.java <==
package com.xforceplus.ultraman.app.jctke.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2022-11-21
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.ultraman.app.jctke.entity.FlowinstancelogLrr94edwdqrcw2ajregmnm;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-tke")
public interface FlowinstancelogLrr94edwdqrcw2ajregmnmFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/flowinstancelogLrr94edwdqrcw2ajregmnm/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param flowinstancelogLrr94edwdqrcw2ajregmnm ${table.comment}
   * @return R
   */
  @PostMapping("/flowinstancelogLrr94edwdqrcw2ajregmnm/add")
  public R save(@RequestBody FlowinstancelogLrr94edwdqrcw2ajregmnm flowinstancelogLrr94edwdqrcw2ajregmnm);

  /**
   * 修改${table.comment}
   * @param flowinstancelogLrr94edwdqrcw2ajregmnm ${table.comment}
   * @return R
   */
  @PostMapping("/flowinstancelogLrr94edwdqrcw2ajregmnm/update")
  public R updateById(@RequestBody FlowinstancelogLrr94edwdqrcw2ajregmnm flowinstancelogLrr94edwdqrcw2ajregmnm);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/flowinstancelogLrr94edwdqrcw2ajregmnm/del/{id}" )
  public R removeById(@PathVariable Long id);

}
